(function ($) {
    "use strict";

    // callback on contact search success
    var contactSearchSuccess = function (contacts) {
        if (contacts.length > 0) {
            var clearedContacts = [];
            for ( var k = 0; k < contacts.length; k++) {
                if (contacts[k].name != null && contacts[k].phoneNumbers != null) {
                    clearedContacts.push(contacts[k]);
                }
            }
            clearedContacts.sort(function (a, b) {
                var c = a.name.formatted.toLowerCase();
                var d = b.name.formatted.toLowerCase();
                if (c < d) return -1;
                if (c > d) return 1;
                return 0;
            });

            var imagePath = 'img/user.png';
            var html = '';
            for (var i = 0; i < clearedContacts.length; i++) {
                var name = clearedContacts[i].name.formatted;
                // phone number
                for (var j = 0; j < clearedContacts[i].phoneNumbers.length; j++) {
                    var clearedPhoneNumber = clearedContacts[i].phoneNumbers[j].value.replace(/\s+/g, "");
 
                    if (clearedPhoneNumber.match(/^(01|00491|\+491)/gi)) {
                        html += '' +
                            '<li class="ui-li-has-thumb">' +
                            '<a data-number="' + clearedPhoneNumber + '" class="number ui-btn ui-btn-icon-right ui-icon-carat-r" href="#">' +
                            '<img alt="' + name  + '" style="margin-left:5px;" class="profile-image" width="70" height="70" src="' + imagePath + '" />' +
                            '<h5>' + name + '</h5><p>' + clearedPhoneNumber + '</p></a>' +
                            '</li>';
                    }
                }
            }
            $('#found-contacts').html(html);
            $('[data-role="content"]').trigger('create');
            $("#wrapper").iscrollview("refresh");
        } else {
            $('#found-contacts').html('<li>Keine Treffer gefunden</li>');
        }

    };

    var delay = (function(){
        var timer = 0;
        return function(callback, ms){
            clearTimeout (timer);
            timer = setTimeout(callback, ms);
        };
    })();

    // callback on search error
    var contactSearchError = function () {
        alert('Unmöglich kontakte zu filtern');
    };

    // start search
    var findContacts = function () {
        $('#found-contacts').html('');
        var pattern = $('#recipient').val().trim();
        doSearch(pattern);
    };

    // execute contact search
    var doSearch = function(pattern) {
        var options = new ContactFindOptions();
        options.filter = pattern;
        options.multiple = true;
        var fields = ["displayName", "phoneNumbers", "photos", "name"];
        navigator.contacts.find(fields, contactSearchSuccess, contactSearchError, options);
    };

    var onResume = function () {
        findContacts();
    };

    var onPause = function () {
        //findContacts();
    };

    // handle .number links
    $(document).on('click', '.number', function () {
        var url = 'http://www.mufa.de/free-sms.html?utm_source=mufa.de%20Free%20SMS%20Adressbuch&utm_medium=app&utm_campaign=Adressbuch&nr=' + encodeURIComponent($(this).attr("data-number"));
        var ref = window.open(url, '_blank', 'location=yes'); // open in InAppBrowser
    });

    $(document).on('checkImage', function() {
        window.requestFileSystem(LocalFileSystem.PERSISTENT, 0, function(){}, function(){});
        $('.profile-image').each(function() {
            var alt = $(this).attr('alt');
            window.resolveLocalFileSystemURI($(this).attr('src'), function(){}, function() { $('img[alt=' + alt + ']').attr('src', 'img/user.png'); });
        });
    });

    // start

    document.addEventListener("deviceready", function () {

        // prevent double click
        var last_click_time = new Date().getTime();
        document.addEventListener('click', function (e) {
            var click_time = e['timeStamp'];
            if (click_time && (click_time - last_click_time) < 1000) {
                e.stopImmediatePropagation();
                e.preventDefault();
                return false;
            }
            last_click_time = click_time;
        }, true);

        StatusBar.overlaysWebView(false);
        StatusBar.backgroundColorByName("gray");
        document.addEventListener("resume", onResume, false);
        document.addEventListener("pause", onPause, false);
        window.addEventListener('load', function() {
            FastClick.attach(document.body);
        }, false);

        var recipient = $('#recipient');
        recipient.on('keyup', function() {
            delay(findContacts, 200);
        });

        // init admob
        if (AdMob) {
            document.addEventListener('onAdFailLoad', function(data){
                console.log('error: ' + data.error +
                ', reason: ' + data.reason +
                ', adNetwork:' + data.adNetwork +
                ', adType:' + data.adType +
                ', adEvent:' + data.adEvent); // adType: 'banner' or 'interstitial'
                $('#loader').hide();
            });
            document.addEventListener('onAdLoaded', function(data){ $('#loader').hide()});
            document.addEventListener('onAdPresent', function(data){});
            document.addEventListener('onAdLeaveApp', function(data){ findContacts(); });
            document.addEventListener('onAdDismiss', function(data){ findContacts() });
            AdMob.prepareInterstitial({adId: 'ca-app-pub-5925074223077002/7846751120', autoShow: true});
        }

    }, true);

})(jQuery);
